@@ -1,35 +1,43 @@
-# LaTeX2HTML 2K.1beta (1.48)
+# LaTeX2HTML 2002-2-1 (1.71)
 # Associate labels original text with physical files.
 
 
 $key = q/sec:apoointerface/;
-$external_labels{$key} = "$URL/" . q|node4.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/sec:files/;
-$external_labels{$key} = "$URL/" . q|node3.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/sec:apootutor/;
 $external_labels{$key} = "$URL/" . q|node5.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/sec:files/;
+$external_labels{$key} = "$URL/" . q|node9.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/sec:apootutor/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/aw/;
-$external_labels{$key} = "$URL/" . q|node4.html|; 
+$external_labels{$key} = "$URL/" . q|node5.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sec:vpu/;
-$external_labels{$key} = "$URL/" . q|node3.html|; 
+$external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/at/;
-$external_labels{$key} = "$URL/" . q|node4.html|; 
+$external_labels{$key} = "$URL/" . q|node5.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/sec:apoovm/;
+$external_labels{$key} = "$URL/" . q|node7.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/download/;
+$external_labels{$key} = "$URL/" . q|node8.html|; 
 $noresave{$key} = "$nosave";
 
 1;
 
 
-# LaTeX2HTML 2K.1beta (1.48)
+# LaTeX2HTML 2002-2-1 (1.71)
 # labels from external_latex_labels array.
 
 
