@@ -1,5 +1,4 @@
-#!/usr/bin/python
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 """
 Apoo Virtual Processor
 
@@ -22,12 +21,15 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 @author: Rogério Reis & Nelma Moreira {rvr,nam}@ncc.up.pt
 """
 from constants import *
-import string, sys, time
+import string, sys, time, copy
+
+
+__version = "$Id: vpu.py,v 1.49 2006-04-14 21:21:00 rvr Exp $"
+
 
-__version = "$Id: vpu.py,v 1.41 2003/08/09 16:55:38 rvr Exp $"
 
 class Vpu:
-    def __init__(self, n=8):
+    def __init__(self, n=8, MpMem = {},Inter=None):
         """This is where all the pseudo-code is specified. Any new
         intruction added shoud be added to the constants.py module
         too, where the lexical information resides.  @arg n: is the
@@ -40,11 +42,14 @@ class Vpu:
         self.labelp = {}
         self.labelm = {}
         self.labelms = {}
+        self.constants = {}
         self.PC = 0
         self.BreakP = []
         self.stack = Stack()
         self.lines = []
         self.time0, self.time = 0,0
+        self.Inter=Inter
+        self.MpMem = copy.deepcopy(MpMem)
         self.code = {'add':("Reg[A2] = Reg[A2] + Reg[A1]",
                             "incPC()"),
                      'and':("Reg[A2] = Reg[A1] & Reg[A2]",
@@ -79,6 +84,12 @@ class Vpu:
                              "else: add = A1",
                              "self.PC = add"),
                      'jumpi':("self.PC = Reg[A1]"),
+                     'jnzero':("if Reg[A1] != 0:",
+                              " if type(A2) == type(''):",
+                              "  add = self.ParseLabelP(A2)",
+                              " else: add = i[2]",
+                              " self.PC = add",
+                              "else: self.PC = self.PC + 1"),
                      'jzero':("if Reg[A1] == 0:",
                               " if type(A2) == type(''):",
                               "  add = self.ParseLabelP(A2)",
@@ -89,12 +100,12 @@ class Vpu:
                              " try: add = self.labelm[A1]",
                              " except KeyError: raise LabelError",
                              "else: add = A1",
-                             "try: foo = RAM[add]",
+                             "try: foo = self.MLoad(add)",
                              "except IndexError: raise OutOfMemory(add)",
                              "Reg[A2] = foo",
                              "incPC()"),
                      'loadi':("add = Reg[A1]",
-                              "try: foo = RAM[add]",
+                              "try: foo = self.MLoad(add)",
                               "except IndexError: raise OutOfMemory(add)",
                               "Reg[A2] = foo",
                               "incPC()"),
@@ -119,10 +130,10 @@ class Vpu:
                               " except KeyError: raise LabelError",
                               "else: add = A2",
                               "foo = Reg[A1]",
-                              "try: RAM[add] = foo",
+                              "try: self.MStore(add,foo)",
                               "except IndexError: raise OutOfMemory(add)",
                               "incPC()"),
-                     'storei':("try: RAM[Reg[A2]] = Reg[A1]",
+                     'storei':("try: self.MStore(Reg[A2],Reg[A1])",
                                "except IndexError:",
                                " raise OutOfMemory(Reg[A2])",
                                "incPC()"),
@@ -145,7 +156,17 @@ class Vpu:
 
     def clean(self):
         """Ensures all the memory areas are clean."""
-        self.__init__()
+        for i in range(self.nreg): self.reg[i]=0
+        self.RAM = []
+        self.Prog = []
+        self.labelp = {}
+        self.labelm = {}
+        self.labelms = {}
+        self.PC = 0
+        self.BreakP = []
+        self.stack = Stack()
+        self.lines = []
+        self.time0, self.time = 0,0
 
     def __str__(self):
         """Only used for debugging purposes."""
@@ -155,6 +176,22 @@ class Vpu:
         """Only used for debugging purposes."""
         return 'Vpu( %s )'% self.__str__()
 
+    def MStore(self,add,val):
+        """Store in memory shell that deals with mapped memory """
+        if add not in self.MpMem.keys():
+            self.RAM[add] = val
+        else:
+            exec self.MpMem[add][1]
+        
+    def MLoad(self,add):
+        """Load from RAM shell that deals with mapped memory """
+        if add not in self.MpMem.keys():
+            return self.RAM[add]
+        else:
+            val = 0
+            exec self.MpMem[add][0]
+            return val
+        
     def run(self, MaxSteps=1000):
         """Starts the execution of the current program.
 
@@ -208,6 +245,18 @@ class Vpu:
             if len(i) < 2:
                 if i[0] == []: raise LabelError(n)
                 else: i.append('nop')
+            if i[1] == 'equ':
+                if len(i) != 3:
+                    raise BadArgs(n)
+                if i[0] == []:
+                    raise BadArgs(n)
+                else:
+                    validateLabelName(i[0],n)
+                    if isNumber(i[2]):
+                        self.constants[i[0]]= int(i[2])
+                    else:
+                        raise BadArgs(n)
+                continue
             if i[1] == 'const':
                 if len(i) != 3:
                     raise BadArgs(n)
@@ -218,11 +267,21 @@ class Vpu:
                     lastLabel = i[0]
                 else:
                     self.labelms[lastLabel] = self.labelms[lastLabel] + 1
-                try: r = int(i[2])
-                except ValueError:
-                    raise NotInt(n)
+                r = charORint(i[2],n)
                 self.RAM.append(r)
                 continue
+            if i[1] == "string":
+                if len(i) != 3:
+                    raise BadArgs(n)
+                strarg = validateString(i[2],n)
+                if i[0] != []:
+                    validateLabelName(i[0],n)
+                    self.labelm[i[0]] = len(self.RAM)
+                    self.labelms[i[0]] = len(strarg)+1
+                for j in strarg:
+                    self.RAM.append(ord(j))
+                self.RAM.append(0)
+                continue
             if i[1] == 'mem':
                 if len(i) != 3:
                     raise BadArgs(n)
@@ -245,7 +304,7 @@ class Vpu:
                 else: self.Prog.append((i[1],))
             elif i[1] in inst[1]: # nonreg
                 if len(i) != 3: raise BadArgs(n)
-                else: self.Prog.append((i[1],ParseNum(i[2])))
+                else: self.Prog.append((i[1],self.ParseNum(i[2])))
             elif i[1] in inst[2]: # reg
                 if len(i) != 3: raise BadArgs(n)
                 r1 = ParseReg(i[2],self.nreg,n)
@@ -258,14 +317,23 @@ class Vpu:
             elif i[1] in inst[4]: # nonreg reg
                 if len(i) != 4: raise BadArgs(n)
                 r1 = ParseReg(i[3],self.nreg,n)
-                self.Prog.append((i[1],ParseNum(i[2]),r1))
+                self.Prog.append((i[1],self.ParseNum(i[2]),r1))
             elif i[1] in inst[5]: # reg nonreg
                 if len(i) != 4: raise BadArgs(n)
                 r1 = ParseReg(i[2],self.nreg,n)
-                self.Prog.append((i[1],r1,ParseNum(i[3])))
+                self.Prog.append((i[1],r1,self.ParseNum(i[3])))
             else:
                 raise IllInst(n)
+            
 
+    def ParseNum(self,st):
+        if st in self.constants.keys():
+            return self.constants[st]
+        elif st[0] in string.digits or st[0] == '-':
+            return int(st)
+        else:
+            return st
+        
     def ParseLabel(self,st):
         try: r = self.labelm[st]
         except KeyError:
@@ -423,12 +491,6 @@ def ParseReg(st,nreg,line):
             raise IllReg(line)
         return i
 
-def ParseNum(st):
-    if st[0] in string.digits or st[0] == '-':
-        return int(st)
-    else:
-        return st
-
 def expandCode(list):
     if type(list) == type(''):
         return expandCode1(list)
@@ -464,6 +526,46 @@ def validateLabelName(str,linenum):
         if i not in string.letters + string.digits:
             raise LabelNameError(linenum)
 
+def validateString(i,n):
+    arg = ""
+    if i[0] != '"' or i[-1] != '"':
+        raise WrongArg(n)
+    flag = False
+    for c in i[1:-1]:
+        if not flag:
+            if c == "\\":
+                flag= True
+            else:
+                arg += c
+        else:
+            flag = False
+            if c=="t":
+                arg += "\t"
+            if c=="s":
+                arg += " "
+            if c == "n":
+                arg += "\n"
+            if c == "\\":
+                arg += "\\"
+    return arg
+
+def charORint(i,n):
+    if i[0] != "'":
+        try: r = int(i)
+        except ValueError:
+            raise WrongArg(n)
+    elif i[-1] != "'": raise WrongArg(n)
+    elif i[1] != "\\" and len(i) != 3: raise WrongArg(n)
+    elif i[1] != "\\": r = ord(i[1])
+    else:
+        if len(i) != 4: raise WrongArg(n)
+        elif i[2] == "n": r = ord("\n")
+        elif i[2] == "s": r = ord(" ")
+        elif i[2] == "t": r = ord("\t")
+        elif i[2] == "\\": r = ord("\\")
+        else: raise WrongArg(n)
+    return r
+
 def isRegName(str):
     """Verifies if this is a register name."""
     if str[0] not in ['r','R']:
@@ -471,3 +573,4 @@ def isRegName(str):
     elif not isNumber(str[1:]):
         return 0
     return 1
+
